
// (c) COPYRIGHT URI/MIT 1996,1997
// Please read the full copyright statement in the file COPYRIGHT.
//
// Authors:
//	reza		Reza Nekovei (reza@intcomm.net)

// This is the main CGI program which extracts the requested variable from a
// DSP imaeg file. It generates the DDS in-memory from both the DSP image
// file and external file and uses it to locate the variable to process.
//
// ReZa 08/29/96

#include "config_dsp.h"

static char *rcsid not_used = "$Id: dsp_dods.cc,v 1.13.4.1 2001/09/17 06:46:49 reza Exp $";

#include <iostream.h>
#include <string>

#include "cgi_util.h"
#include "Error.h"
#include "DODSFilter.h"
#include "DDS.h"

const string cgi_version = DODS_SERVER_VERSION;
extern bool read_descriptors(DDS &dds, const string &filename, string *error);

int 
main(int argc, char *argv[])
{
    DDS dds;
    DODSFilter df(argc, argv);
	
    if (!df.OK()) {
	df.print_usage();
	return 1;
    }

    if (df.version()) {
      df.set_cgi_version(cgi_version);
      df.send_version_info();
      return 0;
    }

    dds.filename(df.get_dataset_name());

    try {
      // Read the dataset descriptor in memory
      string errMsg;
      if (!read_descriptors(dds, df.get_dataset_name(), &errMsg)) {
	ErrMsgT("dsp_dods: could not read the DDS information");
	//client error message
	Error e(unknown_error, errMsg);
	set_mime_text(cout, dods_error);
	e.print(cout);
	return 1;
      }

      df.read_ancillary_dds(dds);

      df.send_data(dds, stdout);
    }
    catch (Error &e) {
      set_mime_text(cout, dods_error, df.get_cgi_version());
      e.print(cout);
      return 1;
    }

    return 0;
}

// $Log: dsp_dods.cc,v $
// Revision 1.13.4.1  2001/09/17 06:46:49  reza
// Added Version support.
//
// Revision 1.13  2000/10/09 21:25:00  jimg
// Moved CVS Log entries to the end of each file.
// Changed the definition of the read method to match the dap library.
// Added exceptions to the read methods.
// Added code to catch exceptions in dsp_das, _dds and _dods.
//
// Revision 1.12  1999/04/30 21:32:48  jimg
// Merged no-gnu and release-2-17
//
// Revision 1.11  1999/01/21 01:43:43  jimg
// Added call to set filename in the DDS. This is required for proper operation
// of the projection functions.
//
// Revision 1.10.8.1  1999/02/10 06:28:59  brent
// convert to Standard C++ strings -- b^2
//
// Revision 1.10  1998/03/20 00:29:52  jimg
// Changed calls to the set_mime_*() to match the new parameters
//
// Revision 1.9  1998/02/05 20:14:23  jimg
// DODS now compiles with gcc 2.8.x
//
// Revision 1.8  1997/08/05 22:44:37  jimg
// Changed type of option_char in `option_char = getopt(...)' from char to
// int. This fixes a bug that shows up on the SGI (where char is unsigned).
//
// Revision 1.7  1997/07/15 17:53:41  jimg
// merged release-2-1-4 changes
//
// Revision 1.5.2.1  1997/07/15 00:49:24  jimg
// Fixed as per Dan's changes for version 2.14; changed the DAS and DDS objects
// so that the are pointers and not global static objects.
//
// Revision 1.6  1997/06/25 21:47:33  jimg
// Added changes from Dan.
//
// Revision 1.5  1997/06/05 17:16:57  jimg
// Rewrote main() so that it uses functions added to cgi_util.cc for the 2.14
// release. These function help to unify the *_dods filters so that they all
// respond more uniformly.
//
// Revision 1.4  1997/03/10 05:41:55  reza
// Added error objects to the code and updated for release 2.12.
// Now the data is sent gzip compressed.
//
// Revision 1.3  1997/02/07 17:49:22  reza
// Fixed so null constraint will return the entire data set now
//
// Revision 1.2  1996/11/15 18:22:32  jimg
// Fixed copyright statement.
// Added include of config header
//
// Revision 1.1  1996/09/18 22:42:30  reza
//  First release of DODS-DSP servers.
//
//
